==> nextcloud-13.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/sr.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Спољашње складиште",
    "Personal" : "Лично",
    "System" : "Систем",
    "Grant access" : "Одобри приступ",
    "Error configuring OAuth1" : "Грешка у подешавању OAuth1",
    "Please provide a valid app key and secret." : "Наведите исправан апликативни кључ и тајну.",
    "Error configuring OAuth2" : "Грешка у подешавању OAuth2",
    "Generate keys" : "Генериши кључеве",
    "Error generating key pair" : "Грешка при генерисању пара кључева",
    "All users. Type to select user or group." : "Сви корисници. Куцајте за избор корисника или групе.",
    "(group)" : "(група)",
    "Compatibility with Mac NFD encoding (slow)" : "Компатибилност са NFD кодирањем (споро)",
    "Admin defined" : "Дефинисао администратор",
    "Are you sure you want to delete this external storage?" : "Да ли стварно желите да обришете ово спољашње складиште?",
    "Delete storage?" : "Обриши складиште?",
    "Saved" : "Сачувано",
    "Saving..." : "Чувам...",
    "Save" : "Сачувај",
    "Empty response from the server" : "Празан одговор са сервера",
    "Couldn't access. Please log out and in again to activate this mount point" : "Не могу да приступим. Одјавите се и пријавите поново да активирате ову тачку монтирања",
    "Couldn't get the information from the remote server: {code} {type}" : "Не могу да дохватим информације са удаљеног сервера: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Не могу да дохватим листу спољних тачака монтирања: {type}",
    "There was an error with message: " : "Догодила се грешка уз поруку:",
    "External mount error" : "Спољна грешка при монтирању",
    "external-storage" : "спољашње-складиште",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Не могу да добавим листу тачака монтирања Виндоуз мрежних дискова: празан одговор са сервера",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Неке од конфигурисаних спољашњих тачака монтирања нису повезане. Кликните на црвени ред(ове) за више информација",
    "Please enter the credentials for the {mount} mount" : "Унесите акредитиве за {mount} тачку монтирања",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Credentials saved" : "Акредитиви снимљени",
    "Credentials saving failed" : "Снимање акредитива није успело",
    "Credentials required" : "Потребни акредитиви",
    "Storage with ID \"%d\" not found" : "Складиште са идентификацијом \"%d\" није пронађено",
    "Invalid backend or authentication mechanism class" : "Неисправан позадински механизам или начин провере идентитета",
    "Invalid mount point" : "Неисправна тачка монтирања",
    "Objectstore forbidden" : "Забрањен приступ",
    "Invalid storage backend \"%s\"" : "Неисправна позадина складишта „%s“",
    "Not permitted to use backend \"%s\"" : "Недозвољени коришћење позадине \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Недозвољено коришћене провере идентитета користећи \"%s\"",
    "Unsatisfied backend parameters" : "Недостају параметри за позадински механизам",
    "Unsatisfied authentication mechanism parameters" : "Недостају параметри за механизам провере идентитета",
    "Insufficient data: %s" : "Недеовољно података: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Корисник не може да мења складиште са идентификацијом \"%d\"",
    "Access key" : "Кључ за приступ",
    "Secret key" : "Тајни кључ ",
    "Builtin" : "Уграђено",
    "None" : "Ништа",
    "OAuth1" : "OAuth1",
    "App key" : "Кључ апликације",
    "App secret" : "Тајна апликације",
    "OAuth2" : "OAuth2",
    "Client ID" : "ИД клијента",
    "Client secret" : "Тајна клијента",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Име OpenStack тенанта",
    "Identity endpoint URL" : "УРЛ идентитета",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Домен",
    "Rackspace" : "Rackspace",
    "API key" : "API кључ",
    "Global credentials" : "Глобални акредитиви",
    "Log-in credentials, save in database" : "Акредитиви за пријаву, чувани у бази",
    "Username and password" : "Корисничко име и лозинка",
    "Log-in credentials, save in session" : "Акредитиви за пријаву, чувани у сесији",
    "User entered, store in database" : "Корисник уноси, чува се у бази",
    "RSA public key" : "RSA јавни кључ",
    "Public key" : "Јавни кључ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Канта",
    "Hostname" : "Име домаћина",
    "Port" : "Порт",
    "Region" : "Регија",
    "Enable SSL" : "Омогући ССЛ",
    "Enable Path Style" : "Омогући стил путање",
    "Legacy (v2) authentication" : "Стара (v2) провера идентитета",
    "WebDAV" : "ВебДАВ",
    "URL" : "УРЛ",
    "Remote subfolder" : "Удаљена потфасцикла",
    "Secure https://" : "Сигурни https://",
    "FTP" : "FTP",
    "Host" : "Домаћин",
    "Secure ftps://" : "Сигурни ftps://",
    "Local" : "локална",
    "Location" : "Локација",
    "Nextcloud" : "Некстклауд",
    "SFTP" : "SFTP",
    "Root" : "Корен",
    "SFTP with secret key login" : "SFTP са пријавом помоћу тајног кључа",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Дели",
    "SMB / CIFS using OC login" : "SMB / CIFS користећи Некстклауд пријаву",
    "Username as share" : "Корисничко име као дељење",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Назив услуге",
    "Request timeout (seconds)" : "Време захтева истекло (секунде)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL подршка за PHP није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP подршка за PHP није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "„%s“ није инсталиран. Монтирање %s није могуће. Затражите од вашег администратора система да га инсталира.",
    "External storage support" : "Подршка за спољашње складиште",
    "No external storage configured or you don't have the permission to configure them" : "Нема конфигурисаних спољашњих складишта или немате потребне дозволе да их конфигуришете",
    "Name" : "Назив",
    "Storage type" : "Тип складишта",
    "Scope" : "Опсег",
    "Enable encryption" : "Укључи шифровање",
    "Enable previews" : "Укључи прегледе",
    "Enable sharing" : "Укључи дељење",
    "Check for changes" : "Проверавај за измене",
    "Never" : "никад",
    "Once every direct access" : "једном при сваком директном приступу",
    "Read only" : "Само за читање",
    "Folder name" : "Назив фасцикле",
    "External storage" : "Спољашње складиште",
    "Authentication" : "Провера идентитета",
    "Configuration" : "Подешавање",
    "Available for" : "Доступно за",
    "Click to recheck the configuration" : "Кликните овде да поново проверите конфигурацију",
    "Add storage" : "Додај складиште",
    "Advanced settings" : "Напредне поставке",
    "Delete" : "Обриши",
    "Allow users to mount external storage" : "Дозволи корисницима да монтирају спољашња складишта",
    "Allow users to mount the following external storage" : "Дозволи корисницима да монтирају следећа спољашња складишта",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Дохватање токена за захтеве није успело. Проверите да ли су апликативни кључ и тајна исправни.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Дохватање токена за приступ није успело. Проверите да ли су апликативни кључ и тајна исправни.",
    "Step 1 failed. Exception: %s" : "Корак 1 није успео. Грешка: %s",
    "Step 2 failed. Exception: %s" : "Корак 2 није успео. Грешка: %s",
    "Dropbox App Configuration" : "Dropbox конфигурација апликације",
    "Google Drive App Configuration" : "Google Drive конфигурација апликације",
    "OpenStack" : "OpenStack",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "No external storage configured" : "Нема подешеног спољашњег складишта",
    "You can add external storages in the personal settings" : "Можете додати спољашња складишта у вашим личним подешавањима",
    "Are you sure you want to delete this external storage" : "Да ли стварно желите да обришете ово спољашње складиште?"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/sr.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Спољашње складиште",
    "Personal" : "Лично",
    "System" : "Систем",
    "Grant access" : "Одобри приступ",
    "Error configuring OAuth1" : "Грешка у подешавању OAuth1",
    "Please provide a valid app key and secret." : "Наведите исправан апликативни кључ и тајну.",
    "Error configuring OAuth2" : "Грешка у подешавању OAuth2",
    "Generate keys" : "Генериши кључеве",
    "Error generating key pair" : "Грешка при генерисању пара кључева",
    "All users. Type to select user or group." : "Сви корисници. Куцајте за избор корисника или групе.",
    "(group)" : "(група)",
    "Compatibility with Mac NFD encoding (slow)" : "Компатибилност са NFD кодирањем (споро)",
    "Admin defined" : "Дефинисао администратор",
    "Are you sure you want to delete this external storage?" : "Да ли стварно желите да обришете ово спољашње складиште?",
    "Delete storage?" : "Обриши складиште?",
    "Saved" : "Сачувано",
    "Saving..." : "Чувам...",
    "Save" : "Сачувај",
    "Empty response from the server" : "Празан одговор са сервера",
    "Couldn't access. Please log out and in again to activate this mount point" : "Не могу да приступим. Одјавите се и пријавите поново да активирате ову тачку монтирања",
    "Couldn't get the information from the remote server: {code} {type}" : "Не могу да дохватим информације са удаљеног сервера: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Не могу да дохватим листу спољних тачака монтирања: {type}",
    "There was an error with message: " : "Догодила се грешка уз поруку:",
    "External mount error" : "Спољна грешка при монтирању",
    "external-storage" : "спољашње-складиште",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Не могу да добавим листу тачака монтирања Виндоуз мрежних дискова: празан одговор са сервера",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Неке од конфигурисаних спољашњих тачака монтирања нису повезане. Кликните на црвени ред(ове) за више информација",
    "Please enter the credentials for the {mount} mount" : "Унесите акредитиве за {mount} тачку монтирања",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Credentials saved" : "Акредитиви снимљени",
    "Credentials saving failed" : "Снимање акредитива није успело",
    "Credentials required" : "Потребни акредитиви",
    "Storage with ID \"%d\" not found" : "Складиште са идентификацијом \"%d\" није пронађено",
    "Invalid backend or authentication mechanism class" : "Неисправан позадински механизам или начин провере идентитета",
    "Invalid mount point" : "Неисправна тачка монтирања",
    "Objectstore forbidden" : "Забрањен приступ",
    "Invalid storage backend \"%s\"" : "Неисправна позадина складишта „%s“",
    "Not permitted to use backend \"%s\"" : "Недозвољени коришћење позадине \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Недозвољено коришћене провере идентитета користећи \"%s\"",
    "Unsatisfied backend parameters" : "Недостају параметри за позадински механизам",
    "Unsatisfied authentication mechanism parameters" : "Недостају параметри за механизам провере идентитета",
    "Insufficient data: %s" : "Недеовољно података: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Корисник не може да мења складиште са идентификацијом \"%d\"",
    "Access key" : "Кључ за приступ",
    "Secret key" : "Тајни кључ ",
    "Builtin" : "Уграђено",
    "None" : "Ништа",
    "OAuth1" : "OAuth1",
    "App key" : "Кључ апликације",
    "App secret" : "Тајна апликације",
    "OAuth2" : "OAuth2",
    "Client ID" : "ИД клијента",
    "Client secret" : "Тајна клијента",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Име OpenStack тенанта",
    "Identity endpoint URL" : "УРЛ идентитета",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Домен",
    "Rackspace" : "Rackspace",
    "API key" : "API кључ",
    "Global credentials" : "Глобални акредитиви",
    "Log-in credentials, save in database" : "Акредитиви за пријаву, чувани у бази",
    "Username and password" : "Корисничко име и лозинка",
    "Log-in credentials, save in session" : "Акредитиви за пријаву, чувани у сесији",
    "User entered, store in database" : "Корисник уноси, чува се у бази",
    "RSA public key" : "RSA јавни кључ",
    "Public key" : "Јавни кључ",
    "RSA private key" : "RSA тајни кључ",
    "Private key" : "Тајни кључ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Канта",
    "Hostname" : "Име домаћина",
    "Port" : "Порт",
    "Region" : "Регија",
    "Enable SSL" : "Омогући ССЛ",
    "Enable Path Style" : "Омогући стил путање",
    "Legacy (v2) authentication" : "Стара (v2) провера идентитета",
    "WebDAV" : "ВебДАВ",
    "URL" : "УРЛ",
    "Remote subfolder" : "Удаљена потфасцикла",
    "Secure https://" : "Сигурни https://",
    "FTP" : "FTP",
    "Host" : "Домаћин",
    "Secure ftps://" : "Сигурни ftps://",
    "Local" : "локална",
    "Location" : "Локација",
    "Nextcloud" : "Некстклауд",
    "SFTP" : "SFTP",
    "Root" : "Корен",
    "SFTP with secret key login" : "SFTP са пријавом помоћу тајног кључа",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Дели",
    "SMB / CIFS using OC login" : "SMB / CIFS користећи Некстклауд пријаву",
    "Username as share" : "Корисничко име као дељење",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Назив услуге",
    "Request timeout (seconds)" : "Време захтева истекло (секунде)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "cURL подршка за PHP није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP подршка за PHP није омогућена или инсталирана. Монтирање %s није могуће. Затражите од вашег администратора система да је инсталира.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "„%s“ није инсталиран. Монтирање %s није могуће. Затражите од вашег администратора система да га инсталира.",
    "External storage support" : "Подршка за спољашње складиште",
    "Adds basic external storage support" : "Додаје основу подршку за спољна складишта",
    "No external storage configured or you don't have the permission to configure them" : "Нема конфигурисаних спољашњих складишта или немате потребне дозволе да их конфигуришете",
    "Name" : "Назив",
    "Storage type" : "Тип складишта",
    "Scope" : "Опсег",
    "Enable encryption" : "Укључи шифровање",
    "Enable previews" : "Укључи прегледе",
    "Enable sharing" : "Укључи дељење",
    "Check for changes" : "Проверавај за измене",
    "Never" : "никад",
    "Once every direct access" : "једном при сваком директном приступу",
    "Read only" : "Само за читање",
    "Folder name" : "Назив фасцикле",
    "External storage" : "Спољашње складиште",
    "Authentication" : "Провера идентитета",
    "Configuration" : "Подешавање",
    "Available for" : "Доступно за",
    "Click to recheck the configuration" : "Кликните овде да поново проверите конфигурацију",
    "Add storage" : "Додај складиште",
    "Advanced settings" : "Напредне поставке",
    "Delete" : "Обриши",
    "Allow users to mount external storage" : "Дозволи корисницима да монтирају спољашња складишта",
    "Allow users to mount the following external storage" : "Дозволи корисницима да монтирају следећа спољашња складишта",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Дохватање токена за захтеве није успело. Проверите да ли су апликативни кључ и тајна исправни.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Дохватање токена за приступ није успело. Проверите да ли су апликативни кључ и тајна исправни.",
    "Step 1 failed. Exception: %s" : "Корак 1 није успео. Грешка: %s",
    "Step 2 failed. Exception: %s" : "Корак 2 није успео. Грешка: %s",
    "Dropbox App Configuration" : "Dropbox конфигурација апликације",
    "Google Drive App Configuration" : "Google Drive конфигурација апликације",
    "OpenStack" : "OpenStack",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "No external storage configured" : "Нема подешеног спољашњег складишта",
    "You can add external storages in the personal settings" : "Можете додати спољашња складишта у вашим личним подешавањима",
    "Are you sure you want to delete this external storage" : "Да ли стварно желите да обришете ово спољашње складиште?"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
